==> MTOS-5.2.3-ru.tar.gz: MTOS-5.2.3-ru/mt-static/mt_es.js <==
/* Movable Type language lexicon for es localization. */

Lexicon['Select Boilerplate'] = 'Seleccionar Texto con formato';
Lexicon['Strikethrough'] = 'Tachado';
Lexicon['Insert Link'] = 'Insertar enlace';
Lexicon['Are you sure you want to remove the filter \'[_1]\'?'] = '¿Está seguro de que desea borrar el filtro \'[_1]\'?';
Lexicon['Insert/Edit Link'] = 'Insertar/Editar enlace';
Lexicon['Make primary'] = 'Hacer primario';
Lexicon['You have unsaved changes to this page that will be lost.'] = 'Tiene cambios no guardados en esta página que se perderán.';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = 'Último guardado automático a las [_1]:[_2]:[_3]';
Lexicon['Select Text Color'] = 'Color de texto';
Lexicon['Bold (Ctrl+B)'] = 'Negrita (Ctrl+B)';
Lexicon['Last'] = 'Último';
Lexicon['Tag must have a valid name'] = 'La etiqueta debe tener un nombre válido';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = '¿Está seguro de que desea borrar estos [_1] roles? Al hacerlo, eliminará los permisos actualmente asignados a cualquier usuario o grupo relacionados con estos roles.';
Lexicon['Underline (Ctrl+U)'] = 'Subrayado (Ctrl+U)';
Lexicon['Source'] = 'Fuente';
Lexicon['Cancel'] = 'Cancelar';
Lexicon['unlock'] = 'desbloquear';
Lexicon['Dimensions'] = 'Tamaño';
Lexicon['Fullscreen'] = 'Pantalla completa';
Lexicon['Italic (Ctrl+I)'] = 'Itálica (Ctrl+I)';
Lexicon['Loading...'] = 'Cargando...';
Lexicon['to mark as spam'] = 'para marcar como spam';
Lexicon['Auto-saving...'] = 'Auto-guardando...';
Lexicon['All [_1] items are selected'] = 'Todos los [_1] elementos están seleccionados';
Lexicon['Are you sure you want to remove [_1] [_2]?'] = '¿Está seguro de que desea borrar [_1] [_2]?';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = '¿Está seguro de que desea borrar este rol? Al hacerlo, eliminará los permisos actualmente asignados a cualquier usuario o grupo relacionados con este rol.';
Lexicon['delete'] = 'borrar';
Lexicon['No Preview Available.'] = 'Vista previa no disponible.';
Lexicon['Are you sure you want to remove [_1] [_2] with [_3] sub [_4]?'] = '¿Está seguro de que desea borrar [_1] [_2] con [_3] sub [_4]?';
Lexicon['You did not select any [_1] to [_2].'] = 'No seleccionó ninguna [_1] sobre la que [_2].';
Lexicon['Boilerplate'] = 'Texto con formato';
Lexicon['Toggle Fullscreen Mode'] = 'Des/Activar modo pantalla completa';
Lexicon['Enter URL:'] = 'Teclee la URL:';
Lexicon['Preview'] = 'Vista previa';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'La etiqueta \'[_2]\' ya existe.  ¿Está seguro de querer combinar \'[_1]\' con \'[_2]\' en todos los blogs?';
Lexicon['Select Filter'] = 'Seleccionar filtro';
Lexicon['[_1] - [_2] of [_3]'] = '[_1] - [_2] de [_3]';
Lexicon['None selected'] = 'Ninguna seleccionada';
Lexicon['Outdent'] = 'Desindentar';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = 'Tiene \<a href=\'[_3]\'\>[quant,_1,comentario,comentarios] de [_2]\<\/a\>';
Lexicon['This field must be an integer'] = 'Este campo debe ser un número entero';
Lexicon['Insert Image Asset'] = 'Insertar imagen';
Lexicon['Strong Emphasis'] = 'Énfasis negrita';
Lexicon['disable'] = 'deshabilitar';
Lexicon['Insert HTML'] = 'Insertar HTML';
Lexicon['enable'] = 'habilitar';
Lexicon['Unlink'] = 'Borrar enlace';
Lexicon['Save Filter'] = 'Guardar filtro';
Lexicon['Select all [_1] items'] = 'Seleccionar los [_1] elementos';
Lexicon['Next'] = 'Siguiente';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = 'Solo puede actuar sobre un máximo de [_1] [_2].';
Lexicon['Emphasis'] = 'Énfasis';
Lexicon['Block Quotation'] = 'Cita';
Lexicon['(None)'] = '(Ninguno)';
Lexicon['Invalid URL'] = 'URL no válida';
Lexicon['Indent'] = 'Indentar';
Lexicon['Align Left'] = 'Alinear izquierda';
Lexicon['[_1] - Filter [_2]'] = '[_1] - Filtro [_2]';
Lexicon['Label \"[_1]\" is already in use.'] = 'La etiqueta \"[_1]\" ya está en uso.';
Lexicon['publish'] = 'Publicar';
Lexicon['This field is required'] = 'Este campo es obligatorio';
Lexicon['Des\cription'] = 'Descripción';
Lexicon['Name'] = 'Nombre';
Lexicon['Add sub category'] = 'Añadir sub categoría';
Lexicon['remove'] = 'borrar';
Lexicon['Insert Asset Link'] = 'Insertar enlace';
Lexicon['[_1] Filter Items have errors'] = '[_1] elementos de filtro tienen errores';
Lexicon['Communication Error ([_1])'] = 'Error de comunicacionesr ([_1])';
Lexicon['Remove'] = 'Borrar';
Lexicon['Alert'] = 'Alerta';
Lexicon['Select Background Color'] = 'Color de fondo';
Lexicon['Enter email address:'] = 'Teclee la dirección de correo-e:';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = 'Tiene \<a href=\'[_3]\'\>[quant,_1,entrada] de [_2]\<\/a\>';
Lexicon['Redo (Ctrl+Y)'] = 'Rehacer (Ctrl+Y)';
Lexicon['Invalid value'] = 'Valor no válido';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '[_1]Publique[_2] el sitio para que los cambios tomen efecto.';
Lexicon['Insert Boilerplate'] = 'Insertar texto con formato';
Lexicon['Invalid date format'] = 'Formato de fecha no válido';
Lexicon['Horizontal Line'] = 'Línea horizontal';
Lexicon['Label is required.'] = 'La etiqueta es obligatoria.';
Lexicon['Prev'] = 'Anterior';
Lexicon['Toggle HTML Edit Mode'] = 'Des/Activar modo edición HTML';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = 'Solo puede actuar sobre un mínimo de [_1] [_2].';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = '¿Está seguro de que desea [_3] el/los [_1] seleccionado/s [_2]?';
Lexicon['This field must be a number'] = 'Este campo debe ser un número';
Lexicon['[_1] \'[_2]\' already exists.'] = '[_1] \'[_2]\' ya existe.';
Lexicon['to remove spam status'] = 'para desmarcar como spam';
Lexicon['Unordered List'] = 'Lista no ordenada';
Lexicon['Invalid email address'] = 'Dirección de correo no válida';
Lexicon['Align Right'] = 'Alinear centro';
Lexicon['Align Center'] = 'Alinear derecha';
Lexicon['[_1] contains a character that is invalid when used in a directory name: [_2]'] = '[_1] contiene un caracter no válido para un nombre de directorio: [_2]';
Lexicon['Remove Formatting'] = 'Borrar formato';
Lexicon['You have an error in your input.'] = 'Hay un error en lo que introdujo.';
Lexicon['You must select an action.'] = 'Debe seleccionar una acción.';
Lexicon['Save As Filter'] = 'Guardar como filtro';
Lexicon['File Name'] = 'Nombre fichero';
Lexicon['You did not select any [_1] [_2].'] = 'No seleccionó ninguna [_1] [_2].';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'La etiqueta \'[_2]\' ya existe. ¿Está seguro de que desea integrar \'[_1]\' y \'[_2]\'?';
Lexicon['List Item'] = 'Elemento lista';
Lexicon['No [_1] could be found.'] = 'No se encontraron [_1].';
Lexicon['Add sub folder'] = 'Añadir sub carpeta';
Lexicon['Undo (Ctrl+Z)'] = 'Deshacer (Ctrl+Z)';
Lexicon['Ordered List'] = 'Lista ordenada';
Lexicon['Close'] = 'Cerrar';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'La etiqueta \'[_2]\' ya existe. ¿Está seguro de que desea integrar \'[_1]\' y \'[_2]\' en todos los weblogs?';
Lexicon['First'] = 'Primero';
Lexicon['Are you sure you want to [_2] this [_1]?'] = '¿Está seguro de que desea [_2] esta [_1]?';

==> MTOS-5.12-ru.tar.gz: MTOS-5.12-ru/mt-static/mt_es.js <==
/* Movable Type language lexicon for es localization. */

Lexicon['Are you sure you want to remove the filter \'[_1]\'?'] = '¿Está seguro de que desea borrar el filtro \'[_1]\'?';
Lexicon['Make primary'] = 'Hacer primario';
Lexicon['You have unsaved changes to this page that will be lost.'] = 'Posee cambios no guardados en esta página que se perderán.';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = 'Último guardado automático a las [_1]:[_2]:[_3]';
Lexicon['Last'] = 'Último';
Lexicon['Tag must have a valid name'] = 'La etiqueta debe tener un nombre válido';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = '¿Está seguro de que desea borrar estos [_1] roles? Al hacerlo, eliminará los permisos actualmente asignados a cualquier usuario o grupo relacionados con estos roles.';
Lexicon['Cancel'] = 'Cancelar';
Lexicon['Dimensions'] = 'Tamaño';
Lexicon['Loading...'] = 'Cargando...';
Lexicon['to mark as spam'] = 'para marcar como spam';
Lexicon['Auto-saving...'] = 'Auto-guardando...';
Lexicon['All [_1] items are selected'] = 'Todos los [_1] elementos están seleccionados';
Lexicon['Are you sure you want to remove [_1] [_2]?'] = '¿Está seguro de que desea borrar [_1] [_2]?';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = '¿Está seguro de que desea borrar este rol? Al hacerlo, eliminará los permisos actualmente asignados a cualquier usuario o grupo relacionados con este rol.';
Lexicon['delete'] = 'borrar';
Lexicon['No Preview Available.'] = 'Vista previa no disponible.';
Lexicon['Are you sure you want to remove [_1] [_2] with [_3] sub [_4]?'] = '¿Está seguro de que desea borrar [_1] [_2] con [_3] sub [_4]?';
Lexicon['You did not select any [_1] to [_2].'] = 'No seleccionó ninguna [_1] sobre la que [_2].';
Lexicon['Enter URL:'] = 'Teclee la URL:';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'La etiqueta \'[_2]\' ya existe.  ¿Está seguro de querer combinar \'[_1]\' con \'[_2]\' en todos los blogs?';
Lexicon['Select Filter'] = 'Seleccionar filtro';
Lexicon['[_1] - [_2] of [_3]'] = '[_1] - [_2] de [_3]';
Lexicon['None selected'] = 'Ninguna seleccionada';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = 'Tiene \<a href=\'[_3]\'\>[quant,_1,comentario,comentarios] de [_2]\<\/a\>';
Lexicon['disable'] = 'deshabilitar';
Lexicon['enable'] = 'habilitar';
Lexicon['Save Filter'] = 'Guardar filtro';
Lexicon['Select all [_1] items'] = 'Seleccionar los [_1] elementos';
Lexicon['Next'] = 'Siguiente';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = 'Solo puede actuar sobre un máximo de [_1] [_2].';
Lexicon['(None)'] = '(Ninguno)';
Lexicon['Invalid URL'] = 'URL no válida';
Lexicon['[_1] - Filter [_2]'] = '[_1] - Filtro [_2]';
Lexicon['Label \"[_1]\" is already in use.'] = 'La etiqueta \"[_1]\" ya está en uso.';
Lexicon['publish'] = 'Publicar';
Lexicon['This field is required'] = 'Este campo es obligatorio';
Lexicon['Add sub category'] = 'Añadir sub categoría';
Lexicon['remove'] = 'borrar';
Lexicon['[_1] Filter Items have errors'] = '[_1] elementos de filtro tienen errores';
Lexicon['Communication Error ([_1])'] = 'Error de comunicacionesr ([_1])';
Lexicon['This field must be integer'] = 'Este campo debe ser un entero';
Lexicon['Remove'] = 'Borrar';
Lexicon['Alert'] = 'Alerta';
Lexicon['Enter email address:'] = 'Teclee la dirección de correo-e:';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = 'Tiene \<a href=\'[_3]\'\>[quant,_1,entrada] de [_2]\<\/a\>';
Lexicon['Invalid value'] = 'Valor no válido';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '[_1]Publique[_2] el sitio para que los cambios tomen efecto.';
Lexicon['Invalid date format'] = 'Formato de fecha no válido Invalid date format';
Lexicon['Label is required.'] = 'La etiqueta es obligatoria.';
Lexicon['Prev'] = 'Anterior';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = 'Solo puede actuar sobre un mínimo de [_1] [_2].';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = '¿Está seguro de que desea [_3] el/los [_1] seleccionado/s [_2]?';
Lexicon['[_1] \'[_2]\' already exists.'] = '[_1] \'[_2]\' ya existe.';
Lexicon['to remove spam status'] = 'para desmarcar como spam';
Lexicon['This field must be number'] = 'Este campo debe ser un número';
Lexicon['[_1] contains a character that is invalid when used in a directory name: [_2]'] = '[_1] contiene un caracter no válido para un nombre de directorio: [_2]';
Lexicon['You must select an action.'] = 'Debe seleccionar una acción.';
Lexicon['Save As Filter'] = 'Guardar como filtro';
Lexicon['File Name'] = 'Nombre fichero';
Lexicon['You did not select any [_1] [_2].'] = 'No seleccionó ninguna [_1] [_2].';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'La etiqueta \'[_2]\' ya existe. ¿Está seguro de que desea integrar \'[_1]\' y \'[_2]\'?';
Lexicon['Invalid mail address'] = 'Dirección de fecha no válida';
Lexicon['No [_1] could be found.'] = 'No se encontraron [_1].';
Lexicon['Add sub folder'] = 'Añadir sub carpeta';
Lexicon['Close'] = 'Cerrar';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'La etiqueta \'[_2]\' ya existe. ¿Está seguro de que desea integrar \'[_1]\' y \'[_2]\' en todos los weblogs?';
Lexicon['First'] = 'Primero';
Lexicon['Are you sure you want to [_2] this [_1]?'] = '¿Está seguro de que desea [_2] esta [_1]?';
